Index: src/gpu/GrPathRendering.h |
diff --git a/src/gpu/GrPathRendering.h b/src/gpu/GrPathRendering.h |
index 3e2cfc6c9aefb345bff2442ebd7b2d11d412ba3a..e198d694dbb94ace09182484036390b3c9507587 100644 |
--- a/src/gpu/GrPathRendering.h |
+++ b/src/gpu/GrPathRendering.h |
@@ -11,12 +11,12 @@ |
#include "SkPath.h" |
#include "GrPathRange.h" |
-class SkStrokeRec; |
class SkDescriptor; |
class SkTypeface; |
class GrPath; |
class GrGpu; |
class GrStencilSettings; |
+class GrStrokeInfo; |
/** |
* Abstract class wrapping HW path rendering API. |
@@ -84,17 +84,17 @@ public: |
* @param stroke the path stroke. |
* @return a new path. |
*/ |
- virtual GrPath* createPath(const SkPath&, const SkStrokeRec&) = 0; |
+ virtual GrPath* createPath(const SkPath&, const GrStrokeInfo&) = 0; |
/** |
* Creates a range of gpu paths with a common stroke. The caller owns a ref on the |
* returned path range which must be balanced by a call to unref. |
* |
* @param PathGenerator class that generates SkPath objects for each path in the range. |
* @param SkStrokeRec the common stroke applied to each path in the range. |
* @return a new path range. |
*/ |
- virtual GrPathRange* createPathRange(GrPathRange::PathGenerator*, const SkStrokeRec&) = 0; |
+ virtual GrPathRange* createPathRange(GrPathRange::PathGenerator*, const GrStrokeInfo&) = 0; |
/** |
* Creates a range of glyph paths, indexed by glyph id. The glyphs will have an |
@@ -117,14 +117,15 @@ public: |
* including with the stroke information baked directly into |
* the outlines. |
* |
* @param SkStrokeRec Common stroke that the GPU will apply to every path. Note that |
* if the glyph outlines contain baked-in strokes from the font |
* descriptor, the GPU stroke will be applied on top of those |
* outlines. |
* |
* @return a new path range populated with glyphs. |
*/ |
- virtual GrPathRange* createGlyphs(const SkTypeface*, const SkDescriptor*, const SkStrokeRec&) = 0; |
+ virtual GrPathRange* createGlyphs(const SkTypeface*, const SkDescriptor*, |
+ const GrStrokeInfo&) = 0; |
virtual void stencilPath(const GrPath*, const GrStencilSettings&) = 0; |
virtual void drawPath(const GrPath*, const GrStencilSettings&) = 0; |
@@ -84,17 +84,17 @@ public: |
* |
* @param PathGenerator class that generates SkPath objects for each path in the range. |
- * @param SkStrokeRec the common stroke applied to each path in the range. |
+ * @param GrStrokeInfo the common stroke applied to each path in the range. |
* @return a new path range. |
*/ |
@@ -117,14 +117,15 @@ public: |
* the outlines. |
* |
- * @param SkStrokeRec Common stroke that the GPU will apply to every path. Note that |
+ * @param GrStrokeInfo Common stroke that the GPU will apply to every path. Note that |
* if the glyph outlines contain baked-in strokes from the font |
* descriptor, the GPU stroke will be applied on top of those |